@@ -24,7 +24,6 @@ class ServicerProxy:
         self.grpc_async = os.environ.get("GRPC_ASYNC", False)
 
     def call_handler(self, action):
-        service_instance = self.create_service()
         if self.grpc_async:
 
             async def async_handler(request, context):
@@ -37,6 +36,7 @@ class ServicerProxy:
                     # INFO - AM - 30/06/2021 - Need this in production environnement to avoid SSL end of files errors when too much connection on database
                     await sync_to_async(close_old_connections)()
 
+                    service_instance = self.create_service()
                     service_instance.request = request
                     service_instance.context = GRPCSocioProxyContext(context, action)
                     service_instance.action = action
@@ -50,11 +50,11 @@ class ServicerProxy:
                 except GRPCException as grpc_error:
                     logger.error({grpc_error})
                     await context.abort(grpc_error.status_code, grpc_error.get_full_details())
-                except Exception as error:
-                    e_type, e_value, e_traceback = sys.exc_info()
-                    grpcHandler = GRPCHandler()
-                    grpcHandler.log_unhandled_exception(e_type, e_value, e_traceback)
-                    await context.abort(grpc.StatusCode.UNKNOWN, str(error))
+                # except Exception as error:
+                #     e_type, e_value, e_traceback = sys.exc_info()
+                #     grpcHandler = GRPCHandler()
+                #     grpcHandler.log_unhandled_exception(e_type, e_value, e_traceback)
+                #     await context.abort(grpc.StatusCode.UNKNOWN, str(error))
                 finally:
                     # INFO - AM - 30/06/2021 - Need this in production environnement to avoid SSL end of files errors when too much connection on database
                     await sync_to_async(close_old_connections)()
@@ -73,6 +73,7 @@ class ServicerProxy:
                     # INFO - AM - 30/06/2021 - Need this in production environnement to avoid SSL end of files errors when too much connection on database
                     close_old_connections()
 
+                    service_instance = self.create_service()
                     service_instance.request = request
                     service_instance.context = GRPCSocioProxyContext(context, action)
                     service_instance.action = action
